import { Chain, Network, PlatformToChains } from "@wormhole-foundation/sdk-base";
import { Platform } from "@wormhole-foundation/sdk-base/dist/cjs";
import { ChainToPlatform } from "@wormhole-foundation/sdk-base/src";
import { ChainContext, Signer, TokenBridge, TokenId, TokenTransferDetails, TransactionId, TxHash, WormholeMessageId, AttestationId } from "@wormhole-foundation/sdk-definitions";
import { Wormhole } from "../wormhole";
import { TransferReceipt, TransferQuote, TransferState, WormholeTransfer } from "../wormholeTransfer";
type TokenTransferVAA = TokenBridge.VAA<"Transfer" | "TransferWithPayload">;
export declare class TokenTransfer<N extends Network = Network> implements WormholeTransfer<"TokenBridge" | "AutomaticTokenBridge"> {
    private readonly wh;
    private _state;
    transfer: TokenTransferDetails;
    txids: TransactionId[];
    vaas?: {
        id: WormholeMessageId;
        vaa?: TokenTransferVAA;
    }[];
    private constructor();
    getTransferState(): TransferState;
    static from<N extends Network>(wh: Wormhole<N>, from: TokenTransferDetails): Promise<TokenTransfer<N>>;
    static from<N extends Network>(wh: Wormhole<N>, from: WormholeMessageId, timeout?: number): Promise<TokenTransfer<N>>;
    static from<N extends Network>(wh: Wormhole<N>, from: TransactionId, timeout?: number): Promise<TokenTransfer<N>>;
    private static fromIdentifier;
    private static fromTransaction;
    initiateTransfer(signer: Signer): Promise<TxHash[]>;
    fetchAttestation(timeout?: number): Promise<AttestationId[]>;
    completeTransfer(signer: Signer): Promise<TxHash[]>;
    static track<N extends Network>(wh: Wormhole<N>, xfer: TokenTransfer<N>, timeout?: number): AsyncGenerator<TransferState.SourceFinalized | TransferState.Attested | TransferState.DestinationFinalized, TransferReceipt<"TokenBridge" | "AutomaticTokenBridge", "Solana" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Algorand" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Btc" | "Base" | "Sei" | "Rootstock" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Sepolia", "Solana" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Algorand" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Btc" | "Base" | "Sei" | "Rootstock" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Sepolia">, unknown>;
    static transfer<N extends Network>(fromChain: ChainContext<N, Platform, Chain>, transfer: TokenTransferDetails, signer: Signer<N, Chain>): Promise<TransactionId[]>;
    static redeem<N extends Network>(toChain: ChainContext<N, Platform, Chain>, vaa: TokenTransferVAA, signer: Signer<N, Chain>, automatic?: boolean): Promise<TransactionId[]>;
    static isTransferComplete<N extends Network, P extends Platform, C extends PlatformToChains<P>>(toChain: ChainContext<N, P, C>, vaa: TokenTransferVAA): Promise<boolean>;
    static getTransferMessage<N extends Network, P extends Platform, C extends PlatformToChains<P>>(chain: ChainContext<N, P, C>, txid: TxHash, timeout?: number): Promise<WormholeMessageId>;
    static getTransferVaa<N extends Network>(wh: Wormhole<N>, key: WormholeMessageId | TxHash, timeout?: number): Promise<TokenTransferVAA>;
    static lookupDestinationToken<N extends Network, SC extends Chain, DC extends Chain>(srcChain: ChainContext<N, ChainToPlatform<SC>, SC>, dstChain: ChainContext<N, ChainToPlatform<DC>, DC>, token: TokenId<SC> | "native"): Promise<TokenId<DC>>;
    static isAutomatic<N extends Network>(wh: Wormhole<N>, vaa: TokenTransferVAA): boolean;
    static validateTransferDetails<N extends Network>(wh: Wormhole<N>, transfer: TokenTransferDetails): Promise<void>;
    static quoteTransfer<N extends Network>(srcChain: ChainContext<N, Platform, Chain>, dstChain: ChainContext<N, Platform, Chain>, transfer: TokenTransferDetails): Promise<TransferQuote>;
    static destinationOverrides<N extends Network>(srcChain: ChainContext<N, Platform, Chain>, dstChain: ChainContext<N, Platform, Chain>, transfer: TokenTransferDetails): Promise<TokenTransferDetails>;
    static getReceipt<N extends Network>(xfer: TokenTransfer<N>): TransferReceipt<"TokenBridge" | "AutomaticTokenBridge", typeof xfer.transfer.from.chain, typeof xfer.transfer.to.chain>;
}
export {};
//# sourceMappingURL=tokenTransfer.d.ts.map