import { Chain, Network, Platform } from "@wormhole-foundation/sdk-base";
import { AttestationId, ChainContext, CircleAttestation, CircleMessage, CircleMessageId, CircleTransferDetails, ProtocolVAA, Signer, TransactionId, TxHash, WormholeMessageId } from "@wormhole-foundation/sdk-definitions";
import { Wormhole } from "../wormhole";
import { TransferQuote, TransferState, WormholeTransfer } from "../wormholeTransfer";
export type AutomaticCircleBridgeVAA<PayloadName extends string> = ProtocolVAA<"AutomaticCircleBridge", PayloadName>;
export declare class CircleTransfer<N extends Network = Network> implements WormholeTransfer<"CircleBridge" | "AutomaticCircleBridge"> {
    private readonly wh;
    private _state;
    transfer: CircleTransferDetails;
    txids: TransactionId[];
    circleAttestations?: {
        id: CircleMessageId;
        message: CircleMessage;
        attestation?: CircleAttestation;
    }[];
    vaas?: {
        id: WormholeMessageId;
        vaa?: AutomaticCircleBridgeVAA<"TransferRelay">;
    }[];
    private constructor();
    getTransferState(): TransferState;
    static from<N extends Network>(wh: Wormhole<N>, from: CircleTransferDetails): Promise<CircleTransfer<N>>;
    static from<N extends Network>(wh: Wormhole<N>, from: WormholeMessageId, timeout?: number): Promise<CircleTransfer<N>>;
    static from<N extends Network>(wh: Wormhole<N>, from: string, // CircleMessage hex encoded
    timeout?: number): Promise<CircleTransfer<N>>;
    static from<N extends Network>(wh: Wormhole<N>, from: TransactionId, timeout?: number): Promise<CircleTransfer<N>>;
    private static fromWormholeMessageId;
    private static fromCircleMessage;
    private static fromTransaction;
    initiateTransfer(signer: Signer): Promise<TxHash[]>;
    private _fetchWormholeAttestation;
    private _fetchCircleAttestation;
    fetchAttestation(timeout?: number): Promise<AttestationId[]>;
    completeTransfer(signer: Signer): Promise<TxHash[]>;
    static quoteTransfer<N extends Network>(srcChain: ChainContext<N, Platform, Chain>, dstChain: ChainContext<N, Platform, Chain>, transfer: CircleTransferDetails): Promise<TransferQuote>;
    static getTransferVaa<N extends Network>(wh: Wormhole<N>, wormholeMessageId: WormholeMessageId, timeout?: number): Promise<AutomaticCircleBridgeVAA<"TransferRelay">>;
}
//# sourceMappingURL=cctpTransfer.d.ts.map