import { Chain, Network, Platform, PlatformToChains, ProtocolName } from "@wormhole-foundation/sdk-base";
import { ChainContext, CircleTransferDetails, GatewayTransferDetails, Signer, TokenId, TokenTransferDetails, TransactionId, TxHash, VAA, AttestationId } from "@wormhole-foundation/sdk-definitions";
import { Wormhole } from "./wormhole";
export type TransferRequest<PN extends ProtocolName = ProtocolName> = PN extends "TokenBridge" | "AutomaticTokenBridge" ? TokenTransferDetails : PN extends "CircleBridge" | "AutomaticCircleBridge" ? CircleTransferDetails : PN extends "IbcBridge" ? GatewayTransferDetails : never;
export declare enum TransferState {
    Failed = -1,
    Created = 1,
    SourceInitiated = 2,
    SourceFinalized = 3,
    Attested = 4,
    DestinationInitiated = 5,
    DestinationFinalized = 6
}
export type TransferReceipt<PN extends ProtocolName, SC extends Chain = Chain, DC extends Chain = Chain> = {
    state: TransferState;
    from: SC;
    to: DC;
    originTxs: TransactionId<SC>[];
    destinationTxs: TransactionId<DC>[];
    attestation?: AttestationId<PN>;
};
export type TransferQuote = {
    sourceToken: {
        token: TokenId;
        amount: bigint;
    };
    destinationToken: {
        token: TokenId;
        amount: bigint;
    };
    relayFee?: {
        token: TokenId;
        amount: bigint;
    };
    destinationNativeGas?: bigint;
};
export interface TransferProtocol<PN extends ProtocolName> {
    isTransferComplete<N extends Network, P extends Platform, C extends PlatformToChains<P>>(toChain: ChainContext<N, P, C>, vaa: VAA): Promise<boolean>;
    isAutomatic<N extends Network>(wh: Wormhole<N>, vaa: VAA): boolean;
    quoteTransfer(xfer: WormholeTransfer<PN>): Promise<TransferQuote>;
    getReceipt(xfer: WormholeTransfer<PN>): TransferReceipt<PN>;
    track<N extends Network>(wh: Wormhole<N>, xfer: WormholeTransfer<PN>, timeout: number): AsyncGenerator<TransferState, TransferReceipt<PN>, unknown>;
}
export interface WormholeTransfer<PN extends ProtocolName> {
    transfer: TransferRequest<PN>;
    getTransferState(): TransferState;
    initiateTransfer(signer: Signer): Promise<TxHash[]>;
    fetchAttestation(timeout?: number): Promise<AttestationId[]>;
    completeTransfer(signer: Signer): Promise<TxHash[]>;
}
//# sourceMappingURL=wormholeTransfer.d.ts.map